********************************************************************************
******************************Dataset "balance_sheets"**************************
********************************************************************************
use $datain/balance_sheets/balance_sheets_revenue.dta, clear
foreach x in spending_c spending_k servizi {
merge 1:1 cod_ente year using $datain/balance_sheets/balance_sheets_`x'.dta, nogen
}
save $dataout/balance_sheets_full, replace

/*Match with istat codes */
use $dataout/balance_sheets_full, clear
do $datain/misc/accenti_correzione /*correct accents of municipality names */
merge m:1 mun using $datain/istat/key /*match with demographic identifiers from ISTAT missing = 4.364% */
drop _merge

/*Match with population data */
rename codicecomunenumericocon110p cod_istat
merge m:1 cod_istat year using $datain/istat/population
drop if cod_ente==.

/*Fill missing observations for 1998 and 1999 and interpolate population for missing values*/
bys cod_ente: gen pop2000=pop if year==2000
bys cod_ente: egen mpop2000=max(pop2000)
replace pop=mpop2000 if pop==. & (year==1999 | year==1998)
sort cod_ente year
sort cod_ente year
foreach x in pop pop_l {
bys cod_ente: fillmissing `x', with(previous)
bys cod_ente: fillmissing `x', with(next)
bys cod_ente: fillmissing `x', with(mean)
}
drop _merge mpop2000 pop2000 

*CPI deflated
merge m:1 year using $datain/istat/cpi.dta, nogen 
label variable cpi "Consumer price index, year 2018=1"

qui {
foreach i in irpef_a irpef_rc irpef_rr fondo_solid_a fondo_solid_rc fondo_solid_rr tasi_a tasi_rc tasi_rr tari_a tari_rc tari_rr  imposte_a imposte_rc imposte_rr ici_a ici_rc ici_rr iciap_a iciap_rc iciap_rr energia_a energia_rc energia_rr other_tax_a other_tax_rc other_tax_rr tasse_a tasse_rc tasse_rr rifiuti_a rifiuti_rc rifiuti_rr add_rifiuti_a add_rifiuti_rc add_rifiuti_rr tributi_speciali_a tributi_speciali_rc tributi_speciali_rr totale_entrate_trib_a totale_entrate_trib_rc totale_entrate_trib_rr contributi_stato_a contributi_stato_rc contributi_stato_rr contributi_regione_a contributi_regione_rc contributi_regione_rr contributi_int_a contributi_int_rc contributi_int_rr totale_contributi_a totale_contributi_rc totale_contributi_rr proventi_servizipub_a proventi_servizipub_rc proventi_servizipub_rr proventi_materna_a proventi_materna_rc proventi_materna_rr proventi_elementare_a proventi_elementare_rc proventi_elementare_rr proventi_media_a proventi_media_rc proventi_media_rr proventi_ass_a proventi_ass_rc proventi_ass_rr proventi_nido_a proventi_nido_rc proventi_nido_rr totale_entrate_extrat_a totale_entrate_extrat_rc totale_entrate_extrat_rr trasferimenti_k_stato_a trasferimenti_k_stato_rc trasferimenti_k_stato_rr trasferimenti_k_regione_a trasferimenti_k_regione_rc trasferimenti_k_regione_rr trasferimenti_k_altri_a trasferimenti_k_altri_rc trasferimenti_k_altri_rr trasferimenti_k_province_a trasferimenti_k_province_rc trasferimenti_k_province_rr trasferimenti_k_straord_a trasferimenti_k_straord_rc trasferimenti_k_straord_rr trasferimenti_k_fam_a trasferimenti_k_fam_rc trasferimenti_k_fam_rr totale_entrate_tras_a totale_entrate_tras_rc totale_entrate_tras_rr anticipazioni_rc anticipazioni_rr finanziamenti_a finanziamenti_rc finanziamenti_rr mutui_a mutui_rc mutui_rr obbligazioni_a obbligazioni_rc obbligazioni_rr totale_entrate_prestiti_a totale_entrate_prestiti_rc totale_entrate_prestiti_rr totale_generale_entrate_a totale_generale_entrate_rc totale_generale_entrate_rr totale_entrate_trib_c totale_entrate_trib_c totale_entrate_trib_r totale_contributi_c totale_contributi_r  contributi_amm_pubbliche_a contributi_amm_pubbliche_c contributi_amm_pubbliche_r contributi_famiglie_a contributi_famiglie_c contributi_famiglie_r  contributi_imprese_a contributi_imprese_c contributi_imprese_r contributi_privati_a  contributi_privati_c  contributi_privati_r contributi_estero_a  contributi_estero_c contributi_estero_r  totale_trasferimenti_a  totale_trasferimenti_c  totale_trasferimenti_r totale_entrate_extrat_c totale_entrate_extrat_r totale_entrate_tras_c totale_entrate_tras_r obbligazioni_c obbligazioni_r  prestiti_breve_a prestiti_breve_c prestiti_breve_r  mutui_c  mutui_r  altri_debiti_a altri_debiti_c altri_debiti_r  prestiti_a  prestiti_c prestiti_r  totale_generale_entrate_c totale_generale_entrate_r  {
replace `i'=`i'*cpi
}

foreach i in cur_amm_i cur_giu_i cur_pol_i cur_ist_per_i cur_ist_acq_i cur_ist_ser_i cur_ist_ter_i cur_ist_tra_i cur_ist_int_i cur_ist_tas_i cur_ist_one_i cur_ist_amm_i cur_ist_tot_i cur_ist_mat_per_i cur_ist_mat_acq_i cur_ist_mat_ser_i cur_ist_mat_ter_i cur_ist_mat_tra_i cur_ist_mat_int_i cur_ist_mat_tas_i cur_ist_mat_one_i cur_ist_mat_amm_i cur_ist_mat_tot_i cur_ist_ele_per_i cur_ist_ele_acq_i cur_ist_ele_ser_i cur_ist_ele_ter_i cur_ist_ele_tra_i cur_ist_ele_int_i cur_ist_ele_tas_i cur_ist_ele_one_i cur_ist_ele_amm_i cur_ist_ele_tot_i cur_ist_med_per_i cur_ist_med_acq_i cur_ist_med_ser_i cur_ist_med_ter_i cur_ist_med_tra_i cur_ist_med_int_i cur_ist_med_tas_i cur_ist_med_one_i cur_ist_med_amm_i cur_ist_med_tot_i cur_ist_ass_per_i cur_ist_ass_acq_i cur_ist_ass_ser_i cur_ist_ass_ter_i cur_ist_ass_tra_i cur_ist_ass_int_i cur_ist_ass_tas_i cur_ist_ass_one_i cur_ist_ass_amm_i cur_ist_ass_tot_i cur_cul_i cur_spo_i cur_tur_i cur_tra_i cur_amb_i cur_soc_per_i cur_soc_acq_i cur_soc_ser_i cur_soc_ter_i cur_soc_tra_i cur_soc_int_i cur_soc_tas_i cur_soc_one_i cur_soc_amm_i cur_soc_tot_i cur_soc_nid_per_i cur_soc_nid_acq_i cur_soc_nid_ser_i cur_soc_nid_ter_i cur_soc_nid_tra_i cur_soc_nid_int_i cur_soc_nid_tas_i cur_soc_nid_one_i cur_soc_nid_amm_i cur_soc_nid_tot_i cur_svi_i cur_ser_i cur_amm_per_rc cur_amm_acq_rc cur_amm_ser_rc cur_amm_ter_rc cur_amm_tra_rc cur_amm_int_rc cur_amm_tas_rc cur_amm_one_rc cur_amm_amm_rc cur_amm_tot_rc cur_giu_rc cur_pol_rc cur_ist_per_rc cur_ist_acq_rc cur_ist_ser_rc cur_ist_ter_rc cur_ist_tra_rc cur_ist_int_rc cur_ist_tas_rc cur_ist_one_rc cur_ist_amm_rc cur_ist_tot_rc cur_ist_mat_per_rc cur_ist_mat_acq_rc cur_ist_mat_ser_rc cur_ist_mat_ter_rc cur_ist_mat_tra_rc cur_ist_mat_int_rc cur_ist_mat_tas_rc cur_ist_mat_one_rc cur_ist_mat_amm_rc cur_ist_mat_tot_rc cur_ist_ele_per_rc cur_ist_ele_acq_rc cur_ist_ele_ser_rc cur_ist_ele_ter_rc cur_ist_ele_tra_rc cur_ist_ele_int_rc cur_ist_ele_tas_rc cur_ist_ele_one_rc cur_ist_ele_amm_rc cur_ist_ele_tot_rc cur_ist_med_per_rc cur_ist_med_acq_rc cur_ist_med_ser_rc cur_ist_med_ter_rc cur_ist_med_tra_rc cur_ist_med_int_rc cur_ist_med_tas_rc cur_ist_med_one_rc cur_ist_med_amm_rc cur_ist_med_tot_rc cur_ist_ass_per_rc cur_ist_ass_acq_rc cur_ist_ass_ser_rc cur_ist_ass_ter_rc cur_ist_ass_tra_rc cur_ist_ass_int_rc cur_ist_ass_tas_rc cur_ist_ass_one_rc cur_ist_ass_amm_rc cur_ist_ass_tot_rc cur_cul_rc cur_spo_rc cur_tur_rc cur_tra_rc cur_amb_rc cur_soc_per_rc cur_soc_acq_rc cur_soc_ser_rc cur_soc_ter_rc cur_soc_ter_rc cur_soc_tra_rc cur_soc_int_rc cur_soc_tas_rc cur_soc_one_rc cur_soc_amm_rc cur_soc_tot_rc cur_soc_nid_per_rc cur_soc_nid_acq_rc cur_soc_nid_ser_rc cur_soc_nid_ter_rc cur_soc_nid_tra_rc cur_soc_nid_int_rc cur_soc_nid_tas_rc cur_soc_nid_one_rc cur_soc_nid_amm_rc cur_soc_nid_tot_rc cur_svi_rc cur_ser_rc cur_amm_per_rr cur_amm_acq_rr cur_amm_ser_rr cur_amm_ter_rr cur_amm_tra_rr cur_amm_int_rr cur_amm_tas_rr cur_amm_one_rr cur_amm_amm_rr cur_amm_tot_rr cur_giu_rr cur_pol_rr cur_ist_per_rr cur_ist_acq_rr cur_ist_ser_rr cur_ist_ter_rr cur_ist_tra_rr cur_ist_int_rr cur_ist_tas_rr cur_ist_one_rr cur_ist_amm_rr cur_ist_tot_rr cur_ist_mat_per_rr cur_ist_mat_acq_rr cur_ist_mat_ser_rr cur_ist_mat_ter_rr cur_ist_mat_tra_rr cur_ist_mat_int_rr cur_ist_mat_tas_rr cur_ist_mat_one_rr cur_ist_mat_amm_rr cur_ist_mat_tot_rr cur_ist_ele_per_rr cur_ist_ele_acq_rr cur_ist_ele_ser_rr cur_ist_ele_ter_rr cur_ist_ele_tra_rr cur_ist_ele_int_rr cur_ist_ele_tas_rr cur_ist_ele_one_rr cur_ist_ele_amm_rr cur_ist_ele_tot_rr cur_ist_med_per_rr cur_ist_med_acq_rr cur_ist_med_ser_rr cur_ist_med_ter_rr cur_ist_med_tra_rr cur_ist_med_int_rr cur_ist_med_tas_rr cur_ist_med_one_rr cur_ist_med_amm_rr cur_ist_med_tot_rr cur_ist_ass_per_rr cur_ist_ass_acq_rr cur_ist_ass_ser_rr cur_ist_ass_ter_rr cur_ist_ass_tra_rr cur_ist_ass_int_rr cur_ist_ass_tas_rr cur_ist_ass_one_rr cur_ist_ass_amm_rr cur_ist_ass_tot_rr cur_cul_rr cur_spo_rr cur_tur_rr cur_tra_rr cur_amb_rr cur_soc_per_rr cur_soc_acq_rr cur_soc_ser_rr cur_soc_ter_rr cur_soc_tra_rr cur_soc_int_rr cur_soc_tas_rr cur_soc_one_rr cur_soc_amm_rr cur_soc_tot_rr cur_soc_nid_per_rr cur_soc_nid_acq_rr cur_soc_nid_ser_rr cur_soc_nid_ter_rr cur_soc_nid_tra_rr cur_soc_nid_int_rr cur_soc_nid_tas_rr cur_soc_nid_one_rr cur_soc_nid_amm_rr cur_soc_nid_tot_rr cur_svi_rr cur_ser_rr cur_amm_rr cur_ist_sup_per_i cur_ist_sup_acq_i cur_ist_sup_ser_i cur_ist_sup_ter_i cur_ist_sup_tra_i cur_ist_sup_int_i cur_ist_sup_tas_i cur_ist_sup_one_i cur_ist_sup_amm_i cur_ist_sup_tot_i cur_ist_sup_per_rc cur_ist_sup_acq_rc cur_ist_sup_ser_rc cur_ist_sup_ter_rc cur_ist_sup_tra_rc cur_ist_sup_int_rc cur_ist_sup_tas_rc cur_ist_sup_one_rc cur_ist_sup_amm_rc cur_ist_sup_tot_rc cur_ist_sup_per_rr cur_ist_sup_acq_rr cur_ist_sup_ser_rr cur_ist_sup_ter_rr cur_ist_sup_tra_rr cur_ist_sup_int_rr cur_ist_sup_tas_rr cur_ist_sup_one_rr cur_ist_sup_amm_rr cur_ist_sup_tot_rr cur_tot_rc cur_tot_i cur_tot_p cap_tot_rc cap_tot_i cap_tot_p fin_rc fin_i fin_p pres_rc pres_i pres_p amm_rc amm_i amm_p giu_rc giu_i giu_p pol_rc pol_i pol_p cur_ist_pre_rc cur_ist_pre_i cur_ist_pre_p cap_ist_pre_rc cap_ist_pre_i cap_ist_pre_p ist_pre_tot_rc ist_pre_tot_i ist_pre_tot_p cur_ist_nonuni_rc cur_ist_nonuni_i cur_ist_nonuni_p cap_ist_nonuni_rc cap_ist_nonuni_i cap_ist_nonuni_p ist_nonuni_tot_rc ist_nonuni_tot_i ist_nonuni_tot_p ist_uni_tot_rc ist_uni_tot_i ist_uni_tot_p ist_sup_tot_rc ist_sup_tot_i ist_sup_tot_p ist_aus_tot_rc ist_aus_tot_i ist_aus_tot_p ist_dir_tot_rc ist_dir_tot_i ist_dir_tot_p ist_tot_rc ist_tot_i ist_tot_p cul_rc cul_i cul_p spo_rc spo_i spo_p tur_rc tur_i tur_p ter_rc ter_i ter_p amb_rc amb_i amb_p tra_rc tra_i tra_p soc_rc soc_i soc_p sal_rc sal_i sal_p svi_rc svi_i svi_p lav_rc lav_i lav_p deb_rc deb_i deb_p {
replace `i'=`i'*cpi
}

foreach i in cap_amm_i cap_giu_i cap_pol_i cap_ist_imm_i cap_ist_esp_i cap_ist_acq_i cap_ist_ter_i cap_ist_mob_i cap_ist_inc_i cap_ist_tra_i cap_ist_par_i cap_ist_cap_i cap_ist_con_i cap_ist_tot_i cap_ist_mat_imm_i cap_ist_mat_esp_i cap_ist_mat_acq_i cap_ist_mat_ter_i cap_ist_mat_mob_i cap_ist_mat_inc_i cap_ist_mat_tra_i cap_ist_mat_par_i cap_ist_mat_cap_i cap_ist_mat_con_i cap_ist_mat_tot_i cap_ist_ele_imm_i cap_ist_ele_esp_i cap_ist_ele_acq_i cap_ist_ele_ter_i cap_ist_ele_mob_i cap_ist_ele_inc_i cap_ist_ele_tra_i cap_ist_ele_par_i cap_ist_ele_cap_i cap_ist_ele_con_i cap_ist_ele_tot_i cap_ist_med_imm_i cap_ist_med_esp_i cap_ist_med_acq_i cap_ist_med_ter_i cap_ist_med_mob_i cap_ist_med_inc_i cap_ist_med_tra_i cap_ist_med_par_i cap_ist_med_cap_i cap_ist_med_con_i cap_ist_med_tot_i cap_ist_ass_imm_i cap_ist_ass_esp_i cap_ist_ass_acq_i cap_ist_ass_ter_i cap_ist_ass_mob_i cap_ist_ass_inc_i cap_ist_ass_tra_i cap_ist_ass_par_i cap_ist_ass_cap_i cap_ist_ass_con_i cap_ist_ass_tot_i cap_cul_i cap_spo_i cap_tur_i cap_tra_i cap_amb_i cap_soc_imm_i cap_soc_esp_i cap_soc_acq_i cap_soc_ter_i cap_soc_mob_i cap_soc_inc_i cap_soc_tra_i cap_soc_par_i cap_soc_cap_i cap_soc_con_i cap_soc_tot_i cap_soc_nid_imm_i cap_soc_nid_esp_i cap_soc_nid_acq_i cap_soc_nid_ter_i cap_soc_nid_mob_i cap_soc_nid_inc_i cap_soc_nid_tra_i cap_soc_nid_par_i cap_soc_nid_cap_i cap_soc_nid_con_i cap_soc_nid_tot_i cap_svi_i cap_ser_i cap_amm_rc cap_giu_rc cap_pol_rc cap_ist_imm_rc cap_ist_esp_rc cap_ist_acq_rc cap_ist_ter_rc cap_ist_mob_rc cap_ist_inc_rc cap_ist_tra_rc cap_ist_par_rc cap_ist_cap_rc cap_ist_con_rc cap_ist_tot_rc cap_ist_mat_imm_rc cap_ist_mat_esp_rc cap_ist_mat_acq_rc cap_ist_mat_ter_rc cap_ist_mat_mob_rc cap_ist_mat_inc_rc cap_ist_mat_tra_rc cap_ist_mat_par_rc cap_ist_mat_cap_rc cap_ist_mat_con_rc cap_ist_mat_tot_rc cap_ist_ele_imm_rc cap_ist_ele_esp_rc cap_ist_ele_acq_rc cap_ist_ele_ter_rc cap_ist_ele_mob_rc cap_ist_ele_inc_rc cap_ist_ele_tra_rc cap_ist_ele_par_rc cap_ist_ele_cap_rc cap_ist_ele_con_rc cap_ist_ele_tot_rc cap_ist_med_imm_rc cap_ist_med_esp_rc cap_ist_med_acq_rc cap_ist_med_ter_rc cap_ist_med_mob_rc cap_ist_med_inc_rc cap_ist_med_tra_rc cap_ist_med_par_rc cap_ist_med_cap_rc cap_ist_med_con_rc cap_ist_med_tot_rc cap_ist_ass_imm_rc cap_ist_ass_esp_rc cap_ist_ass_acq_rc cap_ist_ass_ter_rc cap_ist_ass_mob_rc cap_ist_ass_inc_rc cap_ist_ass_tra_rc cap_ist_ass_par_rc cap_ist_ass_cap_rc cap_ist_ass_con_rc cap_ist_ass_tot_rc cap_cul_rc cap_spo_rc cap_tur_rc cap_tra_rc cap_amb_rc cap_soc_imm_rc cap_soc_esp_rc cap_soc_acq_rc cap_soc_ter_rc cap_soc_mob_rc cap_soc_inc_rc cap_soc_tra_rc cap_soc_par_rc cap_soc_cap_rc cap_soc_con_rc cap_soc_tot_rc cap_soc_nid_imm_rc cap_soc_nid_esp_rc cap_soc_nid_acq_rc cap_soc_nid_ter_rc cap_soc_nid_mob_rc cap_soc_nid_inc_rc cap_soc_nid_tra_rc cap_soc_nid_par_rc cap_soc_nid_cap_rc cap_soc_nid_con_rc cap_soc_nid_tot_rc cap_svi_rc cap_ser_rc cap_amm_rr cap_giu_rr cap_pol_rr cap_ist_imm_rr cap_ist_esp_rr cap_ist_acq_rr cap_ist_ter_rr cap_ist_mob_rr cap_ist_inc_rr cap_ist_tra_rr cap_ist_par_rr cap_ist_cap_rr cap_ist_con_rr cap_ist_tot_rr cap_ist_mat_imm_rr cap_ist_mat_esp_rr cap_ist_mat_acq_rr cap_ist_mat_ter_rr cap_ist_mat_mob_rr cap_ist_mat_inc_rr cap_ist_mat_tra_rr cap_ist_mat_par_rr cap_ist_mat_cap_rr cap_ist_mat_con_rr cap_ist_mat_tot_rr cap_ist_ele_imm_rr cap_ist_ele_esp_rr cap_ist_ele_acq_rr cap_ist_ele_ter_rr cap_ist_ele_mob_rr cap_ist_ele_inc_rr cap_ist_ele_tra_rr cap_ist_ele_par_rr cap_ist_ele_cap_rr cap_ist_ele_con_rr cap_ist_ele_tot_rr cap_ist_med_imm_rr cap_ist_med_esp_rr cap_ist_med_acq_rr cap_ist_med_ter_rr cap_ist_med_mob_rr cap_ist_med_inc_rr cap_ist_med_tra_rr cap_ist_med_par_rr cap_ist_med_cap_rr cap_ist_med_con_rr cap_ist_med_tot_rr cap_ist_ass_imm_rr cap_ist_ass_esp_rr cap_ist_ass_acq_rr cap_ist_ass_ter_rr cap_ist_ass_mob_rr cap_ist_ass_inc_rr cap_ist_ass_tra_rr cap_ist_ass_par_rr cap_ist_ass_cap_rr cap_ist_ass_con_rr cap_ist_ass_tot_rr cap_cul_rr cap_spo_rr cap_tur_rr cap_tra_rr cap_amb_rr cap_soc_imm_rr cap_soc_esp_rr cap_soc_acq_rr cap_soc_ter_rr cap_soc_mob_rr cap_soc_inc_rr cap_soc_tra_rr cap_soc_par_rr cap_soc_cap_rr cap_soc_con_rr cap_soc_tot_rr cap_soc_nid_imm_rr cap_soc_nid_esp_rr cap_soc_nid_acq_rr cap_soc_nid_ter_rr cap_soc_nid_mob_rr cap_soc_nid_inc_rr cap_soc_nid_tra_rr cap_soc_nid_par_rr cap_soc_nid_cap_rr cap_soc_nid_con_rr cap_soc_nid_tot_rr cap_svi_rr cap_ser_rr {	
replace `i'=`i'*cpi	
}
}

/* Variabili di cassa */
foreach var in cur_amm cur_giu cur_pol cur_ist_tot cur_soc_tot cur_cul cur_spo cur_tur cur_tra cur_amb cur_svi cur_ser cap_amm cap_giu cap_pol cap_ist_tot cap_soc_tot cap_cul cap_spo cap_tur cap_tra cap_amb cap_svi cap_ser {
replace  `var'_rc=0 if `var'_rc==.
replace  `var'_rr=0 if `var'_rr==.
gen `var'=`var'_rc+`var'_rr
}

destring codiceregione, replace
destring codicedellunitàterritoriales, replace 

xtset cod_ente year
bys cod_ente: gen lpop=L.pop
bys cod_ente: replace lpop=F.pop if year==1998

save $dataout/balance_sheets_clean, replace

