use $dataout/balance_sheets_clean, clear

*Remove duplicates
xtset cod_ente year
bys cod_istat year: gen n=_n
drop if n>1

*Fill missing for development spending
bys cod_ente: egen mean=mean(cap_svi_i)
replace cap_svi_i=mean if cap_svi_i==.

*Cohort averages
forvalues i=2011(1)2017 {
local d=`i'-9
gen cohort`i'=0
replace cohort`i'=1 if year>=`d' & year <= `i'
}
qui {
foreach c in cur cap {
foreach var in amm_i giu_i pol_i ist_tot_i soc_tot_i cul_i spo_i tur_i tra_i amb_i svi_i ser_i amm giu pol ist_tot soc_tot cul spo tur tra amb svi ser {
forvalues i=2011(1)2017 {
bys cod_ente: egen m`c'_`var'_`i'=mean(`c'_`var') if cohort`i'==1
}
}
}
foreach c in cur cap {
foreach var in amm_i giu_i pol_i ist_tot_i soc_tot_i cul_i spo_i tur_i tra_i amb_i svi_i ser_i amm giu pol ist_tot soc_tot cul spo tur tra amb svi ser {
gen c_`c'_`var'=.
forvalues i=2011(1)2017 {
replace c_`c'_`var'=m`c'_`var'_`i' if year==`i'-9
}
}
}
}

qui {
foreach var in cur_ist_per_i cur_ist_acq_i cur_ist_ser_i cur_ist_ter_i cur_ist_tra_i cur_ist_int_i cur_ist_tas_i cur_ist_one_i cur_ist_amm_i {
forvalues i=2011(1)2017 {
bys cod_ente: egen m_`var'_`i'=mean(`var') if cohort`i'==1
}
}
foreach var in cur_ist_per_i cur_ist_acq_i cur_ist_ser_i cur_ist_ter_i cur_ist_tra_i cur_ist_int_i cur_ist_tas_i cur_ist_one_i cur_ist_amm_i  {
gen c_`var'=.
forvalues i=2011(1)2017 {
replace c_`var'=m_`var'_`i' if year==`i'-9
}
}
}

gen current_sp=cur_amm_i+cur_ist_tot_i+cur_cul_i+cur_spo_i+cur_tur_i+cur_tra_i+cur_svi_i+cur_ser_i
gen capital_sp=cap_amm_i+cap_ist_tot_i+cap_cul_i+cap_spo_i+cap_tur_i+cap_tra_i+cap_svi_i+cap_ser_i

*Actual disbursed spending 
gen current_sp_rc=cur_amm_rc+cur_ist_tot_rc+cur_cul_rc+cur_spo_rc+cur_tur_rc+cur_tra_rc+cur_svi_rc+cur_ser_rc+cur_amm_rr+cur_ist_tot_rr+cur_cul_rr+cur_spo_rr+cur_tur_rr+cur_tra_rr+cur_svi_rr+cur_ser_rr
gen capital_sp_rc=cap_amm_rc+cap_ist_tot_rc+cap_cul_rc+cap_spo_rc+cap_tur_rc+cap_tra_rc+cap_svi_rc+cap_ser_rc+cap_amm_rr+cap_ist_tot_rr+cap_cul_rr+cap_spo_rr+cap_tur_rr+cap_tra_rr+cap_svi_rr+cap_ser_rr

qui {
foreach var in current_sp_rc capital_sp_rc {
forvalues i=2011(1)2017 {
bys cod_ente: egen m_`var'_`i'=mean(`var') if cohort`i'==1
}
}

foreach var in current_sp_rc capital_sp_rc {
gen c_`var'=.
forvalues i=2011(1)2017 {
replace c_`var'=m_`var'_`i' if year==`i'-9
}
}
}

destring codiceregione, replace

gen reg_sp=0
replace reg_sp=1 if codiceregione==2 | codiceregione==4 | codiceregione==6 | codiceregione==19 | codiceregione==20

*Capital spending with depreciation rate
foreach var in cap_amm_i cap_giu_i cap_pol_i cap_ist_tot_i cap_soc_tot_i cap_cul_i cap_spo_i cap_tur_i cap_tra_i cap_amb_i cap_svi_i cap_ser_i capital_sp capital_sp_rc {
forvalues i=2002(1)2015 {
gen an_`var'_`i'=`var' if year==`i'
bys cod_ente: egen `var'_`i'=max(an_`var'_`i') 
}
}

foreach var in cap_amm_i cap_giu_i cap_pol_i cap_ist_tot_i cap_soc_tot_i cap_cul_i cap_spo_i cap_tur_i cap_tra_i cap_amb_i cap_svi_i cap_ser_i capital_sp_rc {
local d 0.07
gen cdep_`var'=.
replace cdep_`var'=`var'_2002*(1-`d'*10)+`var'_2003*(1-`d'*9)+`var'_2004*(1-`d'*8)+`var'_2005*(1-`d'*7)+`var'_2006*(1-`d'*6)+`var'_2007*(1-`d'*5)+`var'_2008*(1-`d'*4)+`var'_2009*(1-`d'*3)+`var'_2010*(1-`d'*2)+`var'_2011*(1-`d'*1) if year==2002
replace cdep_`var'=`var'_2003*(1-`d'*10)+`var'_2004*(1-`d'*9)+`var'_2005*(1-`d'*8)+`var'_2006*(1-`d'*7)+`var'_2007*(1-`d'*6)+`var'_2008*(1-`d'*5)+`var'_2009*(1-`d'*4)+`var'_2010*(1-`d'*3)+`var'_2011*(1-`d'*2)+`var'_2012*(1-`d'*1) if year==2003
replace cdep_`var'=`var'_2004*(1-`d'*10)+`var'_2005*(1-`d'*9)+`var'_2006*(1-`d'*8)+`var'_2007*(1-`d'*7)+`var'_2008*(1-`d'*6)+`var'_2009*(1-`d'*5)+`var'_2010*(1-`d'*4)+`var'_2011*(1-`d'*3)+`var'_2012*(1-`d'*2)+`var'_2013*(1-`d'*1) if year==2004
replace cdep_`var'=`var'_2005*(1-`d'*10)+`var'_2006*(1-`d'*9)+`var'_2007*(1-`d'*8)+`var'_2008*(1-`d'*7)+`var'_2009*(1-`d'*6)+`var'_2010*(1-`d'*5)+`var'_2011*(1-`d'*4)+`var'_2012*(1-`d'*3)+`var'_2013*(1-`d'*2)+`var'_2014*(1-`d'*1) if year==2005
replace cdep_`var'=`var'_2006*(1-`d'*10)+`var'_2007*(1-`d'*9)+`var'_2008*(1-`d'*8)+`var'_2009*(1-`d'*7)+`var'_2010*(1-`d'*6)+`var'_2011*(1-`d'*5)+`var'_2012*(1-`d'*4)+`var'_2013*(1-`d'*3)+`var'_2014*(1-`d'*2)+`var'_2015*(1-`d'*1) if year==2006
replace cdep_`var'=`var'_2007*(1-`d'*10)+`var'_2008*(1-`d'*9)+`var'_2009*(1-`d'*8)+`var'_2010*(1-`d'*7)+`var'_2011*(1-`d'*6)+`var'_2012*(1-`d'*5)+`var'_2013*(1-`d'*4)+`var'_2014*(1-`d'*3)+`var'_2015*(1-`d'*2)+`var'_2015*(1-`d'*1) if year==2007
replace cdep_`var'=`var'_2008*(1-`d'*10)+`var'_2009*(1-`d'*9)+`var'_2010*(1-`d'*8)+`var'_2011*(1-`d'*7)+`var'_2012*(1-`d'*6)+`var'_2013*(1-`d'*5)+`var'_2014*(1-`d'*4)+`var'_2015*(1-`d'*3)+`var'_2015*(1-`d'*2)+`var'_2015*(1-`d'*1) if year==2008
}

*Annual spending
foreach var in current_sp capital_sp {
forvalues i=1998(1)2015 {
gen year_`var'_`i'=`var' if year==`i'
bys cod_ente: egen annual_`var'_`i'=max(year_`var'_`i') 
gen year_`var'_`i'_pc=`var'/pop_l if year==`i'
bys cod_ente: egen annual_`var'_`i'_pc=max(year_`var'_`i'_pc) 
}
}

*Tax rate pre-DSP
merge 1:1 codicecatastaledelcomune year using $dataout/local_tax, nogen
foreach v in tax6 pr_tax_ord pr_tax_fh {
gen p_`v'=`v' if (lpop >= 5000 & year == 2004) | (lpop >= 1000 & lpop < 5000 & year ==  2012) | (lpop > 0 & lpop < 1000 & year==2014)
bys codicecatastaledelcomune: egen pre_`v'=max(p_`v')
}

*Politicians and election information
drop if cod_ente==.
merge 1:1 cod_istat year using $dataout/politicians, nogen

*Taxable income data
drop if cod_ente==.
merge 1:1 codicecatastaledelcomune year using $dataout/income, nogen

*House price data
merge 1:1 codicecatastaledelcomune year using $dataout/house_prices, nogen

rename (contributi_int_a contributi_regione_a contributi_stato_a totale_contributi_a) (contributi_int contributi_reg contributi_stato tot_contributi)

qui {
foreach var in y_avg compr mayor_sex mayor_degree mayor_age gender degree age tax6 pr_tax_ord pr_tax_fh tot_contributi  {
forvalues i=2011(1)2017 {
bys cod_ente: egen m_`var'_`i'=mean(`var') if cohort`i'==1
}
}
foreach var in y_avg compr  mayor_sex mayor_degree mayor_age gender degree age tax6 pr_tax_ord pr_tax_fh tot_contributi  {
gen c_`var'=.
forvalues i=2011(1)2017 {
replace c_`var'=m_`var'_`i' if year==`i'-9
}
}
}

*Spending share pre-DSP
foreach v in cur cap {
gen tot_`v'=c_`v'_amm_i+c_`v'_ist_tot_i+c_`v'_cul_i+c_`v'_spo_i+c_`v'_tur_i+c_`v'_svi_i+c_`v'_ser_i+c_`v'_tra_i
}
foreach v in cur cap {
	foreach x in amm_i ist_tot_i cul_i spo_i tur_i svi_i ser_i tra_i {
gen pre_`v'`x'=(c_`v'_`x'/tot_`v') if (lpop >= 5000 & year == 2004) | (lpop >= 1000 & lpop < 5000 & year ==  2012) | (lpop > 0 & lpop < 1000 & year==2014)
bys codicecatastaledelcomune: egen pre_s_`v'_`x'=max(pre_`v'`x')
}
}

*Spending pre-DSP
foreach v in cur cap {
gen p_tot_`v'=(`v'_amm_i+`v'_ist_tot_i+`v'_cul_i+`v'_spo_i+`v'_tur_i+`v'_svi_i+`v'_ser_i+`v'_tra_i)/pop_l if (lpop >= 5000 & year == 2004) | (lpop >= 1000 & lpop < 5000 & year ==  2012) | (lpop > 0 & lpop < 1000 & year==2014)
bys codicecatastaledelcomune: egen pre_tot_`v'=max(p_tot_`v')
}

*Politicians' ability and alignment pre-DSP 
foreach v in mayor_degree degree   {
gen p_`v'=`v' if (lpop >= 5000 & year == 2004) | (lpop >= 1000 & lpop < 5000 & year ==  2012) | (lpop > 0 & lpop < 1000 & year==2014)
bys codicecatastaledelcomune: egen pre_`v'=max(p_`v')
}

save $temp/balance_sheets_year, replace

keep if year >= 2002 & year <= 2008
gen ay=year+9

keep ay lpop c_cur* c_cap* pop_l codicenuts12021 codicenuts32021 codicecatastaledelcomune mun codiceregione reg_sp pre_* mayor_sex-election_year c_y_avg c_compr  c_mayor_sex c_mayor_degree c_mayor_age c_gender c_degree c_age c_tax6 c_pr_tax_fh c_pr_tax_ord cdep* annual*  
compress

save $dataout/balance_sheets, replace

//////
*Merge - dataset final
//////
use $dataout/dataset_invalsi.dta, clear
rename *, lower
keep codice_plesso pu_std_ita pu_std_mat pu_ma_gr pu_ma_no pu_it_gr pu_it_no female cittadinanza regolarita codice_orario-esc edu_padre-ay class_size codice_classe av_class_size codice_scuola gestione-fattore_correzione_new posto_studio-libri_casa pu_corr_ita pu_corr_mat eta 
merge m:1 codicecatastaledelcomune ay using $dataout/balance_sheets
keep if _merge==3
do $datain/misc/comuni_terremotati /*remove municipalities hit by earthquakes */
encode codicenuts12021, gen(p) 
encode codicenuts32021, gen(c3) 
rename codicecatastaledelcomune cod
gen birth_year=ay-9

do $datain/misc/accenti_correzione2 /*correct for accents in municipality names*/

*Match with population 0-10
merge m:1 comune using $datain/istat/population_0_10.dta, nogen

*Generate population 0-10 for each cohort
gen c_pop=.
replace c_pop=(y_2+y_3+y_4+y_5+y_6+y_7+y_8+y_9+y_10+y_11)/10 if birth_year==2002
replace c_pop=(y_3+y_4+y_5+y_6+y_7+y_8+y_9+y_10+y_11+y_12)/10 if birth_year==2003
replace c_pop=(y_4+y_5+y_6+y_7+y_8+y_9+y_10+y_11+y_12+y_13)/10 if birth_year==2004
replace c_pop=(y_5+y_6+y_7+y_8+y_9+y_10+y_11+y_12+y_13+y_14)/10 if birth_year==2005
replace c_pop=(y_6+y_7+y_8+y_9+y_10+y_11+y_12+y_13+y_14+y_15)/10 if birth_year==2006
replace c_pop=(y_7+y_8+y_9+y_10+y_11+y_12+y_13+y_14+y_15+y_16)/10 if birth_year==2007
replace c_pop=(y_8+y_9+y_10+y_11+y_12+y_13+y_14+y_15+y_16+y_17)/10 if birth_year==2008

*Population for depreciated capital spending
local d 0.07
gen cdep_pop=.
replace cdep_pop=y_2*(1-`d'*10)+y_3*(1-`d'*9)+y_4*(1-`d'*8)+y_5*(1-`d'*7)+y_6*(1-`d'*6)+y_7*(1-`d'*5)+y_8*(1-`d'*4)+y_9*(1-`d'*3)+y_10*(1-`d'*2)+y_11*(1-`d'*1) if birth_year==2002
replace cdep_pop=y_3*(1-`d'*10)+y_4*(1-`d'*9)+y_5*(1-`d'*8)+y_6*(1-`d'*7)+y_7*(1-`d'*6)+y_8*(1-`d'*5)+y_9*(1-`d'*4)+y_10*(1-`d'*3)+y_11*(1-`d'*2)+y_12*(1-`d'*1) if birth_year==2003
replace cdep_pop=y_4*(1-`d'*10)+y_5*(1-`d'*9)+y_6*(1-`d'*8)+y_7*(1-`d'*7)+y_8*(1-`d'*6)+y_9*(1-`d'*5)+y_10*(1-`d'*4)+y_11*(1-`d'*3)+y_12*(1-`d'*2)+y_13*(1-`d'*1) if birth_year==2004
replace cdep_pop=y_5*(1-`d'*10)+y_6*(1-`d'*9)+y_7*(1-`d'*8)+y_8*(1-`d'*7)+y_9*(1-`d'*6)+y_10*(1-`d'*5)+y_11*(1-`d'*4)+y_12*(1-`d'*3)+y_13*(1-`d'*2)+y_14*(1-`d'*1) if birth_year==2005
replace cdep_pop=y_6*(1-`d'*10)+y_7*(1-`d'*9)+y_8*(1-`d'*8)+y_9*(1-`d'*7)+y_10*(1-`d'*6)+y_11*(1-`d'*5)+y_12*(1-`d'*4)+y_13*(1-`d'*3)+y_14*(1-`d'*2)+y_15*(1-`d'*1) if birth_year==2006
replace cdep_pop=y_7*(1-`d'*10)+y_8*(1-`d'*9)+y_9*(1-`d'*8)+y_10*(1-`d'*7)+y_11*(1-`d'*6)+y_12*(1-`d'*5)+y_13*(1-`d'*4)+y_14*(1-`d'*3)+y_15*(1-`d'*2)+y_16*(1-`d'*1) if birth_year==2007
replace cdep_pop=y_8*(1-`d'*10)+y_9*(1-`d'*9)+y_10*(1-`d'*8)+y_11*(1-`d'*7)+y_12*(1-`d'*6)+y_13*(1-`d'*5)+y_14*(1-`d'*4)+y_15*(1-`d'*3)+y_16*(1-`d'*2)+y_17*(1-`d'*1) if birth_year==2008

replace mese=99 if mese==. & ay==2011 /*correct for missing information on quarterly of birth in 2011*/
drop if female==. | mese==. | cittadinanza==. | edu_padre==. | edu_madre==. | pu_corr_mat==. | pu_corr_ita==.  | regolarita==. | c_mayor_sex==. | c_mayor_degree==. | c_mayor_age==. | c_gender==. | c_degree==. | c_age==. | election_year==.   

*Define exposure
gen exp=0 
replace exp=ay-2004 if lpop >= 5000
replace exp=ay-2012 if lpop >= 1000 & lpop < 5000 & ay >= 2012
replace exp=ay-2014 if lpop >= 0 & lpop < 1000 & ay >= 2014

*Define current and capital spending
foreach v in cur cap {
gen sp_`v'=((c_`v'_amm_i+c_`v'_ist_tot_i+c_`v'_cul_i+c_`v'_spo_i+c_`v'_tur_i+c_`v'_svi_i+c_`v'_ser_i+c_`v'_tra_i)/c_pop)/1000
gen lsp_`v'=log(sp_`v')
}

*Capital spending with depreciation rate
gen sp_dcap=((cdep_cap_amm_i+cdep_cap_ist_tot_i+cdep_cap_cul_i+cdep_cap_spo_i+cdep_cap_tur_i+cdep_cap_svi_i+cdep_cap_ser_i+cdep_cap_tra_i)/cdep_pop)/1000
bys cod: egen msp_dcap=mean(sp_dcap)
replace sp_dcap=msp_dcap if sp_dcap==.
gen lsp_dcap=log(sp_dcap)
foreach v in cdep_cap_amm_i cdep_cap_ist_tot_i cdep_cap_cul_i cdep_cap_spo_i cdep_cap_tur_i cdep_cap_svi_i cdep_cap_ser_i cdep_cap_tra_i {
replace `v'=(`v'/cdep_pop)/1000
}

*Current spending per-capita
foreach v in cur {
gen sp_`v'_pc=((c_`v'_amm_i+c_`v'_ist_tot_i+c_`v'_cul_i+c_`v'_spo_i+c_`v'_tur_i+c_`v'_svi_i+c_`v'_ser_i+c_`v'_tra_i)/lpop)
gen lsp_`v'_pc=log(sp_`v'_pc)
}

*Capital spending per-capita
foreach v in c_cap {
gen sp_`v'_pc=((`v'_amm_i+`v'_ist_tot_i+`v'_cul_i+`v'_spo_i+`v'_tur_i+`v'_svi_i+`v'_ser_i+`v'_tra_i)/lpop)
gen lsp_`v'_pc=log(sp_`v'_pc)
}
rename (sp_c_cap_pc lsp_c_cap_pc) (sp_dcap_pc lsp_dcap_pc)

bys cod: egen mh=mean(c_compr)
egen mh2=mean(c_compr)
replace c_compr=mh if c_compr==.
replace c_compr=mh2 if c_compr==. /*just 125 missing obs to fill out*/

*Define dosage
xtile quart = pre_s_cur_amm_i, nq(5)
gen dosage=0
replace dosage=1 if quart==1
gen dosageXexp=dosage*exp

drop _merge y_2-pop_tot_y19 mh mh2 

*Save dataset without sample restrictions
save $dataout/dataset_final_norestrictions.dta, replace

*Sample restriction
keep if (cittadinanza==1 | cittadinanza==3) & reg_sp==0 & lpop <= 30000 & gestione=="STATALE"

*Standardize test scores
bys ay: egen mat=std(pu_corr_mat)
bys ay: egen ita=std(pu_corr_ita)

*Spending total
replace sp_dcap=0 if sp_dcap==.
gen sp=sp_cur+sp_dcap
gen lsp=log(sp)

compress

save $dataout/dataset_final.dta, replace

