use $dataout/dataset_final.dta, clear
keep if ay==2011
rename comune COMUNE
merge m:1 COMUNE using $datain/istat/data_mun, nogen

gen date=2005 if POP_2011 >= 5000
replace date=2013 if POP_2011 > 1000 & POP_2011 < 5000
replace date=2015 if POP_2011 < 1000

*Panel a
preserve
local v sp
replace `v'=. if `v'==0
bys COD_PRO: egen mpro=mean(`v')
bys COD_REG: egen mreg=mean(`v')
egen m=mean(`v')
replace `v'=mpro if `v'==.
replace `v'=mreg if `v'==.
replace `v'=m if `v'==.
format `v' %4.3fc	
replace `v'=`v'

replace `v'=. if COD_REG==2 | COD_REG==4 | COD_REG==6  | COD_REG==19 | COD_REG==20  
drop if `v'==.

xtile q = `v', n(4)
forvalues i=1(1)4 {
sum `v' if q==`i', 
gen q_`i' = (r(min))
local q_`i'_`v' = q_`i' `q_`i'_`v''
local q_`i'_`v': di %4.3fc `q_`i'_`v''
}

sum `v' if q==4
gen max = (r(max))
local max_`v' = max
local max_`v': di %4.0fc `max_`v''

collapse sp pre_s_cur_amm_i, by(_ID)

spmap `v' using $datain/istat/data_mun_corr, ///
 id(_ID) graphregion(margin(2 2 2 2) fcolor(white) lcolor(white)) plotregion(lcolor(white)) ///
 line(data($datain/istat/data_reg_corr) color(gs1) size(vvthin)) ///
 ocolor(none none none none) ndo(none) osize(none) fcolor(YlOrRd)  ///
 clmethod(custom) clbreaks(`q_1_`v'' `q_2_`v'' `q_3_`v'' `q_4_`v''  `max_`v'') ///
 legenda(on) legend(size(medium) symxsize(6) keygap(1) rowgap(0.5) r(2) c(3) ///
 label(2 "< `q_2_`v''") label(3 "`q_2_`v''-`q_3_`v''") label(4 "`q_3_`v''-`q_4_`v''")  label(5 "> `q_4_`v''") order(2 3 4 5)) 
 graph export $output/fig1_panelA.png, as(png) replace

*Panel b
restore
preserve
replace date=2013 if POP_2011 > 1000 & POP_2011 < 5000
replace date=2015 if POP_2011 < 1000

replace date=. if COD_REG==2 | COD_REG==4 | COD_REG==6  | COD_REG==19 | COD_REG==20  
drop if date==.

collapse date, by(_ID)

spmap date using $datain/istat/data_mun_corr, ///
 id(_ID) graphregion(margin(2 2 2 2) fcolor(white) lcolor(white)) plotregion(lcolor(white)) ///
 line(data($datain/istat/data_reg_corr) color(gs1) size(vvthin)) ///
 ocolor(none none none none) ndo(none) osize(none) fcolor(YlOrRd)  ///
 clmethod(custom) clbreaks(0 2005 2013 2015) ///
 legenda(on) legend(size(medium) symxsize(6) keygap(1) rowgap(0.5) r(1) c(3) ///
 label(2 "2005") label(3 "2013") label(4 "2015") order(2 3 4))  
 graph export $output/fig1_panelB.png, as(png) replace

*Panel c
restore
preserve
local v pre_s_cur_amm_i
replace `v'=. if `v'==0
bys COD_PRO: egen mpro=mean(`v')
bys COD_REG: egen mreg=mean(`v')
egen m=mean(`v')
replace `v'=mpro if `v'==.
replace `v'=mreg if `v'==.
replace `v'=m if `v'==.
format `v' %4.3fc	
replace `v'=`v'

replace `v'=. if COD_REG==2 | COD_REG==4 | COD_REG==6  | COD_REG==19 | COD_REG==20  
drop if `v'==.

xtile q = `v', n(4)
forvalues i=1(1)4 {
sum `v' if q==`i', 
gen q_`i' = (r(min))
local q_`i'_`v' = q_`i' `q_`i'_`v''
local q_`i'_`v': di %4.3fc `q_`i'_`v''
}

sum `v' if q==4
gen max = (r(max))
local max_`v' = max
local max_`v': di %4.0fc `max_`v''

collapse sp pre_s_cur_amm_i, by(_ID)

spmap `v' using $datain/istat/data_mun_corr, ///
 id(_ID) graphregion(margin(2 2 2 2) fcolor(white) lcolor(white)) plotregion(lcolor(white)) ///
 line(data($datain/istat/data_reg_corr) color(gs1) size(vvthin)) ///
 ocolor(none none none none) ndo(none) osize(none) fcolor(YlOrRd)  ///
 clmethod(custom) clbreaks(`q_1_`v'' `q_2_`v'' `q_3_`v'' `q_4_`v''  `max_`v'') ///
 legenda(on) legend(size(medium) symxsize(6) keygap(1) rowgap(0.5) r(2) c(3) ///
 label(2 "< `q_2_`v''") label(3 "`q_2_`v''-`q_3_`v''") label(4 "`q_3_`v''-`q_4_`v''")  label(5 "> `q_4_`v''") order(2 3 4 5)) 
 graph export $output/fig1_panelC.png, as(png) replace
 
 