use $dataout/dataset_final.dta, clear
merge m:1 codice_scuola ay using  $dataout/dataset_invalsi_dirigenti.dta, nogen

local c female mese cittadinanza edu_padre edu_madre regolarita
local m c_mayor_sex c_mayor_degree c_mayor_age c_gender c_degree c_age
local m2 c_y_avg c_compr

*Home resources
foreach v in internet computer  {
gen d_`v'=.
replace d_`v'=0 if `v'==0 	
replace d_`v'=1 if `v'==1 
}
gen book=.
replace book=0 if libri_casa < 3
replace book=1 if libri_casa >= 3

egen res=rowmean(posto_studio d_computer scrivania enciclopedia d_internet cameretta book)

egen id=group(cod)

bys cod ay prof_madre: egen mres=median(res)
gen low_res=1 if res <= mres
gen high_res=1 if res > mres

*Pre-existing spending
bys cod: egen mexp=min(exp)
bys cod: gen base=sp_cur+sp_dcap if exp==mexp
bys cod: egen b=max(base)
egen q=xtile(b), n(2) by(ay)
gen high_sp=1 if q==2
gen low_sp=1 if q==1 

*Average test score
egen score=rowmean(mat ita)

*No controls
foreach x in sp {
foreach d in low_res high_res low_sp high_sp  {
ivreghdfe score (`x' = exp dosageXexp)  if `d'==1, a(ay cod) cluster(id) 
estimates store `d'_`x'_1
}
}

*Full set of controls
foreach x in sp {
foreach d in low_res high_res low_sp high_sp  {
ivreghdfe score (`x' = exp dosageXexp) `c' `m' `m2'  if `d'==1, a(ay#election_year codice_scuola) cluster(id) 
estimates store `d'_`x'_2
}
}

*Panel A
foreach y in res {
foreach x in sp {
local var low_`y'_`x'_1 high_`y'_`x'_1 low_`y'_`x'_2 high_`y'_`x'_2
coefplot(`var'), ///
  keep(`x') levels(90) aseq swapnames ///
coeflabels(low_`y'_`x'_1 = "Low" ///
high_`y'_`x'_1 = "High"  ///
low_`y'_`x'_2 = "Low" ///
high_`y'_`x'_2 = "High") ///
graphregion(margin(2 2 2 2) fcolor(white) lcolor(white)) plotregion(lcolor(black)) ///
yscale(titlegap(2)) ylabel(, labsize(medium)) grid(none)  ///
xlabel(, valuelabel labsize(medlarge)) xtitle(2SLS coefficient estimate, size(medlarge)) ///
xline(0, lcolor(red) lpattern(solid)) ylabel(, labsize(medlarge)) ///
headings(low_`y'_`x'_1="{bf:Mun and cohort FE}"  low_`y'_`x'_2="{bf:+ other controls:}", labcolor(black) labsize(medlarge)) 
graph export $output/fig3_panelA.png, as(png) replace
}
}

*Panel B
foreach y in sp {
foreach x in sp {
local var low_`y'_`x'_1 high_`y'_`x'_1 low_`y'_`x'_2 high_`y'_`x'_2
coefplot(`var'), ///
  keep(`x') levels(90) aseq swapnames ///
coeflabels(low_`y'_`x'_1 = "Low" ///
high_`y'_`x'_1 = "High"  ///
low_`y'_`x'_2 = "Low" ///
high_`y'_`x'_2 = "High") ///
graphregion(margin(2 2 2 2) fcolor(white) lcolor(white)) plotregion(lcolor(black)) ///
yscale(titlegap(2)) ylabel(, labsize(medium)) grid(none)  ///
xlabel(, valuelabel labsize(medlarge)) xtitle(2SLS coefficient estimate, size(medlarge)) ///
xline(0, lcolor(red) lpattern(solid)) ylabel(, labsize(medlarge)) ///
headings(low_`y'_`x'_1="{bf:Mun and cohort FE}"  low_`y'_`x'_2="{bf:+ other controls:}", labcolor(black) labsize(medlarge)) 
graph export $output/fig3_panelB.png, as(png) replace
}
}
