use $dataout/dataset_final.dta, clear

local c female mese cittadinanza edu_padre edu_madre regolarita
local m c_mayor_sex c_mayor_degree c_mayor_age c_gender c_degree c_age
local m2 c_y_avg c_compr

egen y=rowmean(mat ita)

*Current and capital spending shares
foreach i in amm_i ist_tot_i ser_i cul_i spo_i tur_i tra_i svi_i {
gen lcur_`i'=log(c_cur_`i'+1)
gen lcap_`i'=log(c_cap_`i'+1)
}
	
*Equation 4 (reduced form: estimate b1)
reghdfe y exp dosageXexp `c'  `m' `m2', a(ay cod) cluster(cod) 
lincom exp + dosageXexp
gen b1 = r(estimate)
 
*Equation 5: Coefficients theta
local s cap 
local k cur
reghdfe y exp dosageXexp `c'  `m' `m2' l`s'_amm_i l`s'_ist_tot_i l`s'_cul_i l`s'_spo_i l`s'_tur_i l`s'_tra_i l`s'_svi_i l`s'_ser_i  l`k'_amm_i l`k'_ist_tot_i l`k'_cul_i l`k'_spo_i l`k'_tur_i l`k'_tra_i l`k'_svi_i l`k'_ser_i, a(ay#election_year codice_scuola) cluster(cod) 

foreach v in l`s'_amm_i l`s'_ist_tot_i l`s'_cul_i l`s'_spo_i l`s'_tur_i l`s'_tra_i l`s'_svi_i l`s'_ser_i l`k'_amm_i l`k'_ist_tot_i l`k'_cul_i l`k'_spo_i l`k'_tur_i l`k'_tra_i l`k'_svi_i l`k'_ser_i  {
gen theta_`v'=_b[`v']
}

*Equation 6: salvare i delta
foreach v in l`s'_amm_i l`s'_ist_tot_i l`s'_cul_i l`s'_spo_i l`s'_tur_i l`s'_tra_i l`s'_svi_i l`s'_ser_i l`k'_amm_i l`k'_ist_tot_i l`k'_cul_i l`k'_spo_i l`k'_tur_i l`k'_tra_i l`k'_svi_i l`k'_ser_i {
reghdfe `v' exp dosageXexp `c'  `m' `m2', a(ay#election_year codice_scuola) cluster(cod) 
lincom exp + dosageXexp
gen delta_`v'=r(estimate)
}

*Generate shares
foreach v in l`s'_amm_i l`s'_ist_tot_i l`s'_cul_i l`s'_spo_i l`s'_tur_i l`s'_tra_i l`s'_svi_i l`s'_ser_i l`k'_amm_i l`k'_ist_tot_i l`k'_cul_i l`k'_spo_i l`k'_tur_i l`k'_tra_i l`k'_svi_i l`k'_ser_i  {
gen m_`v'=abs((theta_`v'*delta_`v')/b1)
}

gen type_exp=1
keep m_lcap_* m_lcur_* type_exp
keep if _n==_N

gen amm=m_lcap_amm_i+m_lcur_amm_i
gen edu=m_lcap_ist_tot_i+m_lcur_ist_tot_i 
gen spo=m_lcap_spo_i+m_lcur_spo_i
gen tur=m_lcap_tur_i+m_lcur_tur_i
gen svi=m_lcap_svi_i+m_lcur_svi_i
gen ser=m_lcap_ser_i+m_lcur_ser_i
gen tra=m_lcap_tra_i+m_lcap_tra_i
gen cul=m_lcap_cul_i+m_lcur_cul_i

egen tot_effect=rowtotal(amm edu spo tur svi ser tra cul)
 
foreach v in amm edu spo tur svi ser tra cul {
	gen share_`v'=`v'/tot_effect
}

rename (share_amm share_edu share_spo share_tur share_svi share_ser share_tra share_cul) (share_1 share_2 share_3 share_4 share_5 share_6 share_7 share_8)

keep share*
gen N=1

reshape long share_, i(N) j(item)
rename share_ share
replace share=share*100

gen label="Adm" if item==1
replace label="Edu" if item==2
replace label="Cul" if item==3
replace label="Spo" if item==4
replace label="Tou" if item==5
replace label="Dev" if item==6
replace label="Ser" if item==7
replace label="Roa" if item==8

graph bar (asis) share, over(label, sort(label)) blabel(bar, format(%3.1f)) nofill ///
scheme(viridis) graphregion(margin(0 6 2 2) fcolor(white) lcolor(white)) intensity(50) plotregion(lcolor(white)) ///
  ylabel(0(20)60, labsize(medlarge) nogrid) yscale(titlegap(2)) /// 
  ytitle("Treatment effect explained" "(% of total effect)", size(medlarge)) ///
 blabel(bar, position(outside) format(%9.1f)) ///
 legend(off) 
graph export $output/fig4.png, as(png) replace
