use $dataout/dataset_final_norestrictions.dta, replace

gen public=.
replace public=0 if gestione=="NON STATALE"
replace public=1 if (cittadinanza==1 | cittadinanza==3) & reg_sp==0 & lpop <= 30000 & gestione=="STATALE"
gen private=1 if public==0

*Standardize test scores
bys ay public: egen mat=std(pu_corr_mat)
bys ay public: egen ita=std(pu_corr_ita)

gen sp=sp_cur+sp_cap

keep female mese cittadinanza sp mat ita ay exp edu_padre edu_madre cod codice_scuola regolarita election_year c_mayor_sex c_mayor_degree c_mayor_age c_gender c_degree c_age dosageXexp c_y_avg c_compr public private
	
egen id=group(cod)	
	
*Figure
egen score=rowmean(mat ita)

local y score
local c female mese cittadinanza edu_padre edu_madre regolarita
local m c_mayor_sex c_mayor_degree c_mayor_age c_gender c_degree c_age
local m2 c_y_avg c_compr

foreach x in sp {
foreach d in public private {
ivreghdfe `y' (`x' = exp dosageXexp) if `d'==1, a(ay cod) cluster(id) 
estimates store `x'_`d'_1
	
ivreghdfe `y' (`x' = exp dosageXexp) if `d'==1, a(ay codice_scuola) cluster(id) 
estimates store `x'_`d'_2

ivreghdfe `y' `m' (`x' = exp dosageXexp) if `d'==1, a(ay#election_year codice_scuola) cluster(id) 
estimates store `x'_`d'_3

ivreghdfe `y' `m' `c' (`x' = exp dosageXexp) if `d'==1, a(ay#election_year codice_scuola) cluster(id) 
estimates store `x'_`d'_4
}
}

local x sp 
local var `x'_public_1 `x'_private_1 `x'_public_2 `x'_private_2 `x'_public_3 `x'_private_3 `x'_public_4 `x'_private_4 
coefplot(`var'), ///
  keep(`x') levels(90) aseq swapnames ///
coeflabels(`x'_public_1 = "Public" ///
`x'_private_1 = "Private" ///
`x'_public_2 = "Public" ///
`x'_private_2 = "Private" ///
`x'_public_3 = "Public" ///
`x'_private_3 = "Private" ///
`x'_public_4 = "Public" ///
`x'_private_4 = "Private") ///
graphregion(margin(2 2 2 2) fcolor(white) lcolor(white)) plotregion(lcolor(black)) ///
yscale(titlegap(2)) ylabel(, labsize(medium)) grid(none)  ///
xlabel(0(.01).03, valuelabel labsize(medium)) xtitle(2SLS coefficient estimate) ///
xline(0, lcolor(red) lpattern(solid)) ylabel(, labsize(medsmall)) ///
headings(`x'_public_1="{bf:Baseline:}" `x'_public_2="{bf: + school FE:}" `x'_public_3="{bf: + municipality controls:}" `x'_public_4="{bf: + student controls:}", labcolor(black)) 
graph export $output/fig5.png, as(png) replace
