use $dataout/dataset_final.dta, clear
merge m:1 codice_scuola ay using  $dataout/dataset_invalsi_dirigenti.dta, nogen

local c female mese cittadinanza edu_padre edu_madre regolarita
local m c_mayor_sex c_mayor_degree c_mayor_age c_gender c_degree c_age
local m2 c_y_avg c_compr

egen id=group(cod)

*Principal ability
gen low_pr=1 if titolo_studio_dir < 4 & titolo_studio_dir!=.
gen high_pr=1 if titolo_studio_dir >= 4 & titolo_studio_dir!=. 

*Average test score
egen score=rowmean(mat ita)

*Province and year FE
foreach x in sp  {
foreach d in low_pr high_pr  {
ivreghdfe score (`x' = exp dosageXexp)   if `d'==1, a(ay c3) cluster(id) 
estimates store `d'_`x'_1
}
}

*Full set of controls
foreach x in sp {
foreach d in low_pr high_pr  {
ivreghdfe score (`x' = exp dosageXexp) `c' `m' `m2'  if `d'==1, a(ay#election_year c3) cluster(id) 
estimates store `d'_`x'_2
}
}

local y pr
foreach x in sp  {
local var low_`y'_`x'_1 high_`y'_`x'_1 low_`y'_`x'_2 high_`y'_`x'_2
coefplot(`var'), ///
  keep(`x') levels(90) aseq swapnames ///
coeflabels(low_`y'_`x'_1 = "Low" ///
high_`y'_`x'_1 = "High"  ///
low_`y'_`x'_2 = "Low" ///
high_`y'_`x'_2 = "High") ///
graphregion(margin(2 2 2 2) fcolor(white) lcolor(white)) plotregion(lcolor(black)) ///
yscale(titlegap(2)) ylabel(, labsize(medium)) grid(none)  ///
xlabel(-.005(.005).015, valuelabel labsize(medlarge)) xtitle(2SLS coefficient estimate, size(medlarge)) ///
xline(0, lcolor(red) lpattern(solid)) ylabel(, labsize(medlarge)) ///
headings(low_`y'_`x'_1="{bf:province and cohort FE}"  low_`y'_`x'_2="{bf:+ other controls:}", labcolor(black) labsize(medlarge)) 
graph export $output/fig6.png, as(png) replace
}