use $dataout/dataset_final_norestrictions.dta, clear
keep if (cittadinanza==1 | cittadinanza==3) & reg_sp==0 & lpop <= 100000 & gestione=="STATALE"

rename (pu_corr_mat pu_corr_ita) (mat ita)

local c female mese cittadinanza edu_padre edu_madre regolarita
local m c_mayor_sex c_mayor_degree c_mayor_age c_gender c_degree c_age
local m2 c_y_avg c_compr

gen sp=sp_cur+sp_dcap
gen lsp=log(sp)

keep female mese cittadinanza sp lsp mat ita ay codice_scuola exp lpop dosageXexp female mese cittadinanza edu_padre edu_madre regolarita c_mayor_sex c_mayor_degree c_mayor_age c_gender c_degree c_age c_y_avg c_compr election_year

*A. Upper limit
foreach y in mat ita {
	foreach x in lsp {
preserve
matrix B = [.]
matrix CIL = [.]
matrix CIU = [.]
matrix BW = [.]

forvalues i = 10000(5000)100000 { 			
qui ivreghdfe `y' (`x' = exp dosageXexp) `c'  `m' `m2' if lpop <= `i', a(codice_scuola ay#election_year) cluster(cod) 
local cil = _b[`x'] - _se[`x'] * 1.645
local ciu = _b[`x'] + _se[`x'] * 1.645			
matrix B = [B, _b[`x']]
matrix CIL = [CIL, _b[`x'] -( _se[`x'] * 1.645)]
matrix CIU = [CIU, _b[`x'] +( _se[`x'] * (1.645))]
matrix BW = [BW, `i']
}
			
matrix M = [B \ CIL \ CIU \ BW ]'
svmat M
replace M1 = . if M2 == 0 & M3 == 0
replace M2 = . if M1 == .
replace M3 = . if M1 == .

twoway (line M1 M4, lcolor(black) ) (line M2 M4, lcolor(gs10)  lpattern("--")) ///
(line M3 M4, lcolor(gs10) lpattern("--")) (function y = 0 * x, range(M4) lcolor(red)),  scheme(s1color)  ///
graphregion(color(white)) bgcolor(white) ///
xtitle("Upper population limit", size(medlarge)) xscale(titlegap(2)) ytitle("2SLS coefficient estimate", size(medlarge)) yscale(titlegap(2)) /// 
ylabel(, nogrid labsize(medlarge)) xlabel(10000(20000)100000, labsize(medlarge)) ///
xline(30000, lcolor(red)) ///
legend(off)
graph export $output/appendix/figA6_`y'_`x'_up.png, as(png) replace
restore
}
}

*B. Lower limit
foreach y in mat ita {
	foreach x in lsp {
preserve
matrix B = [.]
matrix CIL = [.]
matrix CIU = [.]
matrix BW = [.]

forvalues i = 500(500)4500 { 			
qui ivreghdfe `y' (`x' = exp dosageXexp) `c'  `m' `m2' if lpop >= `i', a(codice_scuola ay#election_year) cluster(cod) 
local cil = _b[`x'] - _se[`x'] * 1.645
local ciu = _b[`x'] + _se[`x'] * 1.645			
matrix B = [B, _b[`x']]
matrix CIL = [CIL, _b[`x'] -( _se[`x'] * 1.645)]
matrix CIU = [CIU, _b[`x'] +( _se[`x'] * (1.645))]
matrix BW = [BW, `i']
}
			
matrix M = [B \ CIL \ CIU \ BW ]'
svmat M
replace M1 = . if M2 == 0 & M3 == 0
replace M2 = . if M1 == .
replace M3 = . if M1 == .

twoway (line M1 M4, lcolor(black) ) (line M2 M4, lcolor(gs10)  lpattern("--")) ///
(line M3 M4, lcolor(gs10) lpattern("--")) (function y = 0 * x, range(M4) lcolor(red)),  scheme(s1color)  ///
graphregion(color(white)) bgcolor(white) ///
xtitle("Lower population limit", size(medlarge)) xscale(titlegap(2)) ytitle("2SLS coefficient estimate", size(medlarge)) yscale(titlegap(2)) /// 
ylabel(, nogrid labsize(medlarge)) xlabel(500(1000)4500, labsize(medlarge)) ///
legend(off)
graph export $output/appendix/figA6_`y'_`x'_low.png, as(png) replace
restore
}
}

