use $dataout/dataset_final.dta, clear

*Disbursed spending
foreach v in c_current_sp_rc   {
replace `v'=((`v')/c_pop)/1000
gen l`v'=log(`v')
}

*Capital spending with depreciation rate
gen sp_dcap_rc=(cdep_capital_sp_rc/cdep_pop)/1000
bys cod: egen msp_dcap_rc=mean(sp_dcap_rc)
replace sp_dcap_rc=msp_dcap_rc if msp_dcap_rc==.
gen lsp_dcap_rc=log(sp_dcap_rc)

rename (c_current_sp_rc lc_current_sp_rc)  (sp_cur_rc lsp_cur_rc)

local c female mese cittadinanza edu_padre edu_madre regolarita
local m c_mayor_sex c_mayor_degree c_mayor_age c_gender c_degree c_age
local m2 c_y_avg c_compr

keep female mese cittadinanza sp_cur lsp_cur sp_dcap lsp_dcap mat ita ay exp edu_padre edu_madre cod codice_scuola regolarita election_year c_mayor_sex c_mayor_degree c_mayor_age c_gender c_degree c_age c_y_avg c_compr dosageXexp *_rc

egen id=group(cod)
	
foreach y in mat ita   {
foreach x in sp_dcap lsp_dcap  {
ivreghdfe `y' (`x' = exp dosageXexp), a(ay cod) cluster(id) 
local b=_b[`x']	
outreg2 using $output/appendix/tabC8_`y'_`x'.tex, keep(`x') bdec(3) tdec(3) ///
replace addtext(Municipality FE, Yes, School FE, No, Year FE, Yes, Mun Controls, No, Ind controls, No, Other controls, No, p-value, -) nocons 
	
ivreghdfe `y' (`x'_rc = exp dosageXexp), a(ay cod) cluster(id) 
test (`x'_rc)=`b' 
local p = r(p)
local p: di %9.3f `p'
outreg2 using $output/appendix/tabC8_`y'_`x'.tex, keep(`x'_rc) bdec(3) tdec(3) ///
append addtext(Municipality FE, Yes, School FE, No, Year FE, Yes, Mun Controls, No, Ind controls, No, Other controls, No, p-value, `p') nocons 

ivreghdfe `y' (`x' = exp dosageXexp), a(ay codice_scuola) cluster(id) 
local b=_b[`x']	
outreg2 using $output/appendix/tabC8_`y'_`x'.tex, keep(`x') bdec(3) tdec(3) ///
append addtext(Municipality FE, Yes, School FE, Yes, Year FE, Yes, Mun Controls, No, Ind controls, No, Other controls, No, p-value, -) nocons 

ivreghdfe `y' (`x'_rc = exp dosageXexp), a(ay codice_scuola) cluster(id) 
test (`x'_rc)=`b' 
local p = r(p)
local p: di %9.3f `p'
outreg2 using $output/appendix/tabC8_`y'_`x'.tex, keep(`x'_rc) bdec(3) tdec(3) ///
append addtext(Municipality FE, Yes, School FE, Yes, Year FE, Yes, Mun Controls, No, Ind controls, No, Other controls, No, p-value, `p') nocons 

ivreghdfe `y' `m' (`x' = exp dosageXexp), a(ay#election_year codice_scuola) cluster(id) 
local b=_b[`x']	
outreg2 using $output/appendix/tabC8_`y'_`x'.tex, keep(`x') bdec(3) tdec(3) ///
append addtext(Municipality FE, Yes, School FE, Yes, Year FE, Yes, Mun Controls, Yes, Ind controls, No, Other controls, No, p-value, -) nocons 

ivreghdfe `y' `m' (`x'_rc = exp dosageXexp), a(ay#election_year codice_scuola) cluster(id) 
test (`x'_rc)=`b' 
local p = r(p)
local p: di %9.3f `p'
outreg2 using $output/appendix/tabC8_`y'_`x'.tex, keep(`x'_rc) bdec(3) tdec(3) ///
append addtext(Municipality FE, Yes, School FE, Yes, Year FE, Yes, Mun Controls, Yes, Ind controls, No, Other controls, No, p-value, `p') nocons 

ivreghdfe `y' `m' `c' (`x' = exp dosageXexp), a(ay#election_year codice_scuola) cluster(id) 
local b=_b[`x']	
outreg2 using $output/appendix/tabC8_`y'_`x'.tex, keep(`x') bdec(3) tdec(3) ///
append addtext(Municipality FE, Yes, School FE, Yes, Year FE, Yes, Mun Controls, Yes, Ind controls, Yes, Other controls, No, p-value, -) nocons 

ivreghdfe `y' `m' `c' (`x'_rc = exp dosageXexp), a(ay#election_year codice_scuola) cluster(id) 
test (`x'_rc)=`b' 
local p = r(p)
local p: di %9.3f `p'
outreg2 using $output/appendix/tabC8_`y'_`x'.tex, keep(`x'_rc) bdec(3) tdec(3) ///
append addtext(Municipality FE, Yes, School FE, Yes, Year FE, Yes, Mun Controls, Yes, Ind controls, Yes, Other controls, No, p-value, `p') nocons 

ivreghdfe `y' `m' `c' `m2' (`x' = exp dosageXexp), a(ay#election_year codice_scuola) cluster(id) 
local b=_b[`x']	
outreg2 using $output/appendix/tabC8_`y'_`x'.tex, keep(`x') bdec(3) tdec(3) ///
append addtext(Municipality FE, Yes, School FE, Yes, Year FE, Yes, Mun Controls, Yes, Ind controls, Yes, Other controls, Yes, p-value, -) nocons 

ivreghdfe `y' `m' `c' `m2' (`x'_rc = exp dosageXexp), a(ay#election_year codice_scuola) cluster(id) 
test (`x'_rc)=`b' 
local p = r(p)
local p: di %9.3f `p'
outreg2 using $output/appendix/tabC8_`y'_`x'.tex, keep(`x'_rc) bdec(3) tdec(3) ///
append addtext(Municipality FE, Yes, School FE, Yes, Year FE, Yes, Mun Controls, Yes, Ind controls, Yes, Other controls, Yes, p-value, `p') nocons 
}
}